PapyrusHtmlRequest class

A load request that renders an inline HTML string in the webview.

Inheritance

Constructors

PapyrusHtmlRequest({required String html, Uri? baseUri, PapyrusContentMetadata? metadata, List<PapyrusVirtualResource> virtualResources = const []})
const

Properties

baseUri Uri?
final
hashCode int
The hash code for this object.
no setterinherited
html String
final
metadata PapyrusContentMetadata?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
no setteroverride
virtualResources List<PapyrusVirtualResource>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() JsonMap
override
toString() String
A string representation of this object.
inherited
validate() → void
override
withContentSecurityPolicy(String? contentSecurityPolicy) PapyrusHtmlRequest

Operators

operator ==(Object other) bool
The equality operator.
inherited