PapyrusJavaScriptPolicy class

Policy governing JavaScript execution and host-app channel communication.

Constructors

PapyrusJavaScriptPolicy({PapyrusJavaScriptMode mode = PapyrusJavaScriptMode.disabled, Set<String> allowedChannels = const {}, bool allowUserScripts = false, List<PapyrusUserScript> injectedScripts = const []})
Creates a PapyrusJavaScriptPolicy.
const

Properties

allowedChannels Set<String>
final
allowUserScripts bool
final
hashCode int
The hash code for this object.
no setterinherited
injectedScripts List<PapyrusUserScript>
final
mode PapyrusJavaScriptMode
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited