PapyrusUriRequest class
A load request that navigates the webview to a URL.
- Inheritance
-
- Object
- PapyrusLoadRequest
- PapyrusUriRequest
Constructors
-
PapyrusUriRequest({required Uri uri, Map<
String, String> headers = const {}}) -
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → JsonMap -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
) → void -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited